==> owncloud_3.0.0.orig.tar.bz2: owncloud/core/l10n/ru.php <==
<?php $TRANSLATIONS = array(
"Owncloud password reset" => "Сброс пароля OwnCloud",
"Use the following link to reset your password: {link}" => "Используйте следующую ссылку чтобы сбросить пароль: {link}",
"You will receive a link to reset your password via Email." => "На ваш адрес Email выслана ссылка для сброса пароля.",
"Requested" => "Запрошено",
"Login failed!" => "Не удалось войти!",
"Username" => "Имя пользователя",
"Request reset" => "Запросить сброс",
"Your password was reset" => "Ваш пароль был сброшен",
"To login page" => "На страницу авторизации",
"New password" => "Новый пароль",
"Reset password" => "Сбросить пароль",
"Personal" => "Личное",
"Users" => "Пользователи",
"Apps" => "Приложения",
"Admin" => "Администратор",
"Help" => "Помощь",
"Cloud not found" => "Облако не найдено",
"Create an <strong>admin account</strong>" => "Создать <strong>учётную запись администратора</strong>",
"Password" => "Пароль",
"Advanced" => "Дополнительно",
"Data folder" => "Директория с данными",
"Configure the database" => "Настройка базы данных",
"will be used" => "будет использовано",
"Database user" => "Имя пользователя для базы данных",
"Database password" => "Пароль для базы данных",
"Database name" => "Название базы данных",
"Database host" => "Хост базы данных",
"Finish setup" => "Завершить установку",
"web services under your control" => "Сетевые службы под твоим контролем",
"Log out" => "Выйти",
"Settings" => "Настройки",
"Lost your password?" => "Забыли пароль?",
"remember" => "запомнить",
"Log in" => "Войти",
"You are logged out." => "Вы вышли.",
"prev" => "пред",
"next" => "след"
);

==> owncloud-4.0.7.tar.bz2: owncloud/core/l10n/ru.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Имя приложения не установлено.",
"No category to add?" => "Нет категорий для добавления?",
"This category already exists: " => "Эта категория уже существует: ",
"Owncloud password reset" => "Сброс пароля OwnCloud",
"ownCloud password reset" => "Сброс пароля ",
"Use the following link to reset your password: {link}" => "Используйте следующую ссылку чтобы сбросить пароль: {link}",
"You will receive a link to reset your password via Email." => "На ваш адрес Email выслана ссылка для сброса пароля.",
"Requested" => "Запрошено",
"Login failed!" => "Не удалось войти!",
"Username" => "Имя пользователя",
"Request reset" => "Запросить сброс",
"Your password was reset" => "Ваш пароль был сброшен",
"To login page" => "На страницу авторизации",
"New password" => "Новый пароль",
"Reset password" => "Сбросить пароль",
"Personal" => "Личное",
"Users" => "Пользователи",
"Apps" => "Приложения",
"Admin" => "Администратор",
"Help" => "Помощь",
"Access forbidden" => "Доступ запрещён",
"Cloud not found" => "Облако не найдено",
"Edit categories" => "Редактировать категории",
"Add" => "Добавить",
"Create an <strong>admin account</strong>" => "Создать <strong>учётную запись администратора</strong>",
"Password" => "Пароль",
"Advanced" => "Дополнительно",
"Data folder" => "Директория с данными",
"Configure the database" => "Настройка базы данных",
"will be used" => "будет использовано",
"Database user" => "Имя пользователя для базы данных",
"Database password" => "Пароль для базы данных",
"Database name" => "Название базы данных",
"Database host" => "Хост базы данных",
"Finish setup" => "Завершить установку",
"web services under your control" => "Сетевые службы под твоим контролем",
"Log out" => "Выйти",
"Settings" => "Настройки",
"Lost your password?" => "Забыли пароль?",
"remember" => "запомнить",
"Log in" => "Войти",
"You are logged out." => "Вы вышли.",
"prev" => "пред",
"next" => "след"
);
